Overview
========

.. contents::
    :local:
    :backlinks: entry

.. include:: README.rst
   :start-after: START_OF_DOCS_IMPORT
   :end-before: END_OF_DOCS_IMPORT

.. _`Tutorials`: /tutes
.. _`How-To guides`: /howto
.. _`Reference`: /ref
.. _`Background`: /background

.. _`library`: /ref/lib
.. _`command line tools`: /ref/cli

.. _`Release Notes`: /release-notes.html

.. toctree::
    :hidden:
    :maxdepth: 2
    :caption: Tutorials

    tutes/index

.. toctree::
    :hidden:
    :maxdepth: 2
    :caption: How-to Guides

    howto/index
    howto/get-started
    howto/gamma/index
    howto/advanced/index

.. toctree::
    :hidden:
    :maxdepth: 2
    :caption: Reference

    ref/index
    ref/lib/index
    ref/cli/index
    ref/gui/index
    release-notes
    genindex


.. toctree::
    :hidden:
    :maxdepth: 2
    :caption: Background

    background/index
    background/open-source-benefits
    background/autocontouring
    background/elekta-logfiles
    background/file-structure
